#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_skin.interfaces.container import IContainerBaseView
from pyams_skin.layer import IPyAMSLayer
from zope.container.interfaces import IContainer

# import packages
from pyams_skin.table import BaseTable
from pyams_template.template import template_config
from pyramid.view import view_config
from zope.interface import implementer

from pyams_utils import _


@template_config(template='templates/container.pt', layer=IPyAMSLayer)
@implementer(IContainerBaseView)
class ContainerView(object):
    """Base container view"""

    table_class = BaseTable

    def __init__(self, context, request):
        super(ContainerView, self).__init__(context, request)
        self.table = self.table_class(context, request)

    def update(self):
        super(ContainerView, self).update()
        self.table.update()


@view_config(name='delete-element.json', context=IContainer, request_type=IPyAMSLayer,
             permission='manage', renderer='json', xhr=True)
def delete_container_element(request):
    """Delete container element"""
    translate = request.localizer.translate
    name = request.params.get('object_name')
    if not name:
        return {'status': 'message',
                'messagebox': {'status': 'error',
                               'content': translate(_("No provided object_name argument!"))}}
    if name not in request.context:
        return {'status': 'message',
                'messagebox': {'status': 'error',
                               'content': translate(_("Given plug-in name doesn't exist!"))}}
    del request.context[name]
    return {'status': 'success'}
